@@ -344,7 +344,8 @@ def get_improved_geometry(coordinates, event_status, id):
     newCoordinates = cdot_geospatial_api.get_route_between_measures(
         startRouteParams['Route'],
         startRouteParams['Measure'],
-        endRouteParams['Measure'])
+        endRouteParams['Measure'],
+        10)
 
     finalDirection = polygon_tools.get_road_direction_from_coordinates(
         newCoordinates)
